@@ -27,6 +27,7 @@ V1_10_1 = 'v1.10.1'
 V1_10_2 = 'v1.10.2'
 V1_10_3 = 'v1.10.3'
 V1_10_4 = 'v1.10.4'
+V1_10_5 = 'v1.10.5'
 
 
 LINUX = 'linux'
@@ -306,6 +307,7 @@ install_v1_10_1 = functools.partial(install_from_source_code_release, V1_10_1)
 install_v1_10_2 = functools.partial(install_from_source_code_release, V1_10_2)
 install_v1_10_3 = functools.partial(install_from_source_code_release, V1_10_3)
 install_v1_10_4 = functools.partial(install_from_source_code_release, V1_10_4)
+install_v1_10_5 = functools.partial(install_from_source_code_release, V1_10_5)
 
 
 INSTALL_FUNCTIONS = {
@@ -327,6 +329,7 @@ INSTALL_FUNCTIONS = {
         V1_10_2: install_v1_10_2,
         V1_10_3: install_v1_10_3,
         V1_10_4: install_v1_10_4,
+        V1_10_5: install_v1_10_5,
     },
     OSX: {
         V1_9_14: install_v1_9_14,
@@ -346,6 +349,7 @@ INSTALL_FUNCTIONS = {
         V1_10_2: install_v1_10_2,
         V1_10_3: install_v1_10_3,
         V1_10_4: install_v1_10_4,
+        V1_10_5: install_v1_10_5,
     }
 }
 
